//--------------------------------------------------------------------------------------
// File: VisLU2.fx
//
// The effect file for the EmptyProject sample.  
// 
// Copyright (c) Microsoft Corporation. All rights reserved.
//--------------------------------------------------------------------------------------


//--------------------------------------------------------------------------------------
// Global variables
//--------------------------------------------------------------------------------------
float appTime;  //App's time in seconds
float4 arrowcolor;
float arrowTu;
float arrowalpha;
float4x4 worldMatrix;  // World matrix for object
float4x4 transformation; // Transformation of object
float4x4 worldViewProjection;	// World * View * Projection matrix
texture screentex;

struct VS_INPUT 
{
   float3 Position : POSITION0;    
   float2 Texcoord : TEXCOORD0;    
};

struct VS_INPUT_COLOR
{
   float3 Position : POSITION0;    
   float4 Color : COLOR0;    
};

struct VS_OUTPUT 
{
   float4 Position : POSITION0;
   float2 Texcoord : TEXCOORD0;   
};

struct VS_OUTPUT_COLOR
{
   float4 Position : POSITION0;
   float4 Color : COLOR0;   
};

VS_OUTPUT vs_main( VS_INPUT Input )
{
   VS_OUTPUT Output;   
   float4 temp = mul( float4(Input.Position.xyz,1.0f), worldMatrix );
   Output.Position = mul( temp, worldViewProjection );
   Output.Texcoord = Input.Texcoord;       
   return( Output );   
}


VS_OUTPUT vs_main_arrow( VS_INPUT Input )
{
   VS_OUTPUT Output;   
   float4 temp = mul( float4(Input.Position.xyz,1.0f), worldMatrix );
   temp = mul(temp, transformation);
   Output.Position = mul( temp, worldViewProjection );
   Output.Texcoord = Input.Texcoord;       
   return( Output );   
}

VS_OUTPUT_COLOR vs_main_color( VS_INPUT_COLOR Input )
{
   VS_OUTPUT_COLOR Output;   
   float4 temp = mul( float4(Input.Position.xyz,1.0f), worldMatrix );
   Output.Position = mul( temp, worldViewProjection );
   Output.Color = Input.Color;       
   return( Output );   
}

sampler2D screenMap = sampler_state{
	Texture = <screentex>;
	MinFilter = LINEAR;	
    MagFilter = LINEAR;  
    AddressU = BORDER;
    AddressV = BORDER; 
    //AddressW = BORDER;
};

sampler2D screenMap2 = sampler_state{
	Texture = <screentex>;
	MinFilter = POINT;	
    MagFilter = POINT;  
    AddressU = BORDER;
    AddressV = BORDER; 
    //AddressW = BORDER;
};

struct PS_INPUT 
{
   float2 Texcoord : TEXCOORD0; 
};

struct PS_INPUT_COLOR
{
	float4 Color : COLOR0;
};

float4 ps_main( PS_INPUT Input ) : COLOR0
{
   //float4 color = tex2D(screenMap, Input.Texcoord);      
   //if(color.a > 0.0f) color.a = alpha;
   return tex2D(screenMap, Input.Texcoord);
}

float4 ps_main2( PS_INPUT Input ) : COLOR0
{
   return tex2D(screenMap2, Input.Texcoord);      
}


float4 ps_main_color( PS_INPUT_COLOR Input) : COLOR0
{
   return Input.Color;   
}

float4 ps_arrow( PS_INPUT Input ) : COLOR0
{   
   float4 color = arrowcolor;   
   color.a = arrowalpha;
   return color;
}

float4 ps_arrow_gradient( PS_INPUT Input ) : COLOR0
{     
   float4 color = tex2D(screenMap2, float2(arrowTu,0.5f));
   color.a = arrowalpha;
   return color;
}

//--------------------------------------------------------------------------------------
// Techniques (default)
//--------------------------------------------------------------------------------------
technique RenderScene
{
    pass P0
    {     
		VertexShader = compile vs_2_0 vs_main();
        PixelShader  = compile ps_2_0 ps_main();       
    }
}

technique RenderScene2
{
    pass P0
    {     
		VertexShader = compile vs_2_0 vs_main();
        PixelShader  = compile ps_2_0 ps_main2();       
    }
}

technique ArrowPlot
{
    pass P0
    {     
		VertexShader = compile vs_2_0 vs_main_arrow();
        PixelShader  = compile ps_2_0 ps_arrow();       
    }
}

technique ArrowPlotGradient
{
    pass P0
    {     
		VertexShader = compile vs_2_0 vs_main_arrow();
        PixelShader  = compile ps_2_0 ps_arrow_gradient();       
    }
}

technique ColorPlot
{
    pass P0
    {     
		VertexShader = compile vs_2_0 vs_main_color();
        PixelShader  = compile ps_2_0 ps_main_color();       
    }
}
